NAME = "blue_stability"

ICON = "🟦"

DESCRIPTION = f"{ICON} a command interface to stability.ai."

VERSION = "4.48.1"

MARQUEE = (
    "https://github.com/kamangir/AI-ART/raw/main/blue-stability/blue_stability.gif"
)
